@@ -45,6 +45,7 @@
 #include "data.h"
 #include "draw.h"
 #include "error.h"
+#include "hid.h" /* REGISTER_ACTIONS */
 #include "mymem.h"
 #include "misc.h"
 #include "parse_l.h"
@@ -298,17 +299,17 @@ CreateNewVia (DataType *Data,
   SET_FLAG (VIAFLAG, Via);
   Via->ID = ID++;
 
-  /* 
-   * don't complain about MIN_PINORVIACOPPER on a mounting hole (pure
-   * hole)
-   */
+  /* Increase copper diameter to drill hole size if it's lower (unless
+     it's a mounting hole).  This will at least make incrementing the
+     via's copper size reasonably intuitive (i.e. it won't take
+     several increments before the copper is visible). */
   if (!TEST_FLAG (HOLEFLAG, Via) &&
-      (Via->Thickness < Via->DrillingHole + MIN_PINORVIACOPPER))
+      (Via->Thickness < Via->DrillingHole))
     {
-      Via->Thickness = Via->DrillingHole + MIN_PINORVIACOPPER;
-      Message (_("%m+Increased via thickness to %$mS to allow enough copper"
-		 " at %$mD.\n"),
-	       Settings.grid_unit->allow, Via->Thickness, Via->X, Via->Y);
+      Via->Thickness = Via->DrillingHole;
+      Message (_("%m+Warning: Via's pad diameter was below hole size, "
+		 "so pad diameter was increased to hole size at %$mD.\n"),
+	       Settings.grid_unit->allow, Via->X, Via->Y);
     }
 
   SetPinBoundingBox (Via);
@@ -733,7 +734,7 @@ CreateNewElement (DataType *Data, FontType *PCBFont, FlagType Flags,
 {
   ElementType *Element;
 
-#ifdef DEBUG
+#ifdef DEBUG_CREATE_C
   printf("Entered CreateNewElement.....\n");
 #endif
 
@@ -755,7 +756,7 @@ CreateNewElement (DataType *Data, FontType *PCBFont, FlagType Flags,
   Element->Flags = Flags;
   Element->ID = ID++;
 
-#ifdef DEBUG
+#ifdef DEBUG_CREATE_C
   printf("  .... Leaving CreateNewElement.\n");
 #endif
 
@@ -877,9 +878,9 @@ CreateNewPin (ElementType *Element,
 	  pin->DrillingHole = DrillingHole;
 	}
       else if (!TEST_FLAG (HOLEFLAG, pin)
-	       && (pin->DrillingHole > pin->Thickness - MIN_PINORVIACOPPER))
+	       && (pin->DrillingHole > pin->Thickness))
 	{
-	  Message (_("%m+Did not map pin #%s (%s) drill hole because %$mS does not leave enough copper\n"),
+	  Message (_("%m+Did not map pin #%s (%s) drill hole because %$mS does not leave any copper\n"),
 		   Settings.grid_unit->allow, UNKNOWN (Number), UNKNOWN (Name), pin->DrillingHole);
 	  pin->DrillingHole = DrillingHole;
 	}
@@ -1071,3 +1072,46 @@ CreateNewAttribute (AttributeListType *list, char *name, char *value)
   list->Number++;
   return &list->List[list->Number - 1];
 }
+
+/*
+ * Actions
+ */
+
+static const char create_via_syntax[] =
+N_("CreateVia(x,y,[unit])\n");
+
+static const char create_via_help[] =
+N_("Add a via to the board.");
+
+static int
+create_via_action(int argc, char **argv, Coord x, Coord y)
+{
+  char *x_str = ARG (0);
+  char *y_str = ARG (1);
+  char *units = ARG (2);
+  Coord nx, ny;
+  bool absolute1, absolute2;
+  PinType *via;
+  
+  ny = GetValue (y_str, units, &absolute1);
+  nx = GetValue (x_str, units, &absolute2);
+  
+  if (!absolute1 || !absolute2) {
+    Message(
+            "CreateVia action does not currently support relative placements.\n");
+  }
+  
+  via = CreateNewVia(PCB->Data, nx, ny, Settings.ViaThickness,
+                     2*Settings.Keepaway, Settings.ViaMaskAperture,
+                     Settings.ViaDrillingHole, NULL, NoFlags());
+  
+  return via->ID;
+}
+
+static HID_Action create_action_list[] =
+{
+  {"CreateVia", NULL, create_via_action,
+    create_via_help, create_via_syntax}
+};
+
+REGISTER_ACTIONS (create_action_list)
