@@ -409,7 +409,7 @@ Parameter @code{<string>} can be @samp{none}, @samp{mask},
 @item --name-style <string>
 Naming style for individual gerber files.
 Parameter @code{<string>} can be @samp{fixed}, @samp{single},
-@samp{first}, @samp{eagle} or @samp{hackvana}.
+@samp{first}, @samp{eagle}, @samp{hackvana} or @samp{oshpark}.
 @end ftable
 %end-doc
 */
@@ -633,7 +633,7 @@ assign_oshpark_file_suffix (char *dest, int idx)
 }
 
 static void
-assign_file_suffix (char *dest, int idx)
+assign_file_suffix (char *dest, int idx, const char *layer_name)
 {
   int fns_style;
   const char *sext = ".gbr";
@@ -665,7 +665,7 @@ assign_file_suffix (char *dest, int idx)
       break;
     }
 
-  strcpy (dest, layer_type_to_file_name (idx, fns_style));
+  strcpy (dest, layer_type_to_file_name_ex (idx, fns_style, layer_name));
   strcat (dest, sext);
 }
 
@@ -884,7 +884,7 @@ gerber_set_layer (const char *name, int group, int empty)
       f = NULL;
 
       pagecount++;
-      assign_file_suffix (filesuff, idx);
+      assign_file_suffix (filesuff, idx, name);
       f = fopen (filename, "wb");   /* Binary needed to force CR-LF */
       if (f == NULL) 
 	{
