@@ -66,6 +66,7 @@
 #include "misc.h"
 #include "rats.h"
 #include "find.h"
+#include "flags.h"
 
 #include "hid.h"
 #include "hid_draw.h"
@@ -425,7 +426,7 @@ gsvit_create_netlist (void)
     /*! \todo Add fancy color attachment here. */
 
     InitConnectionLookup ();
-    ClearFlagOnAllObjects (false, FOUNDFLAG | SELECTEDFLAG);
+    ClearFlagOnAllObjects (FOUNDFLAG | SELECTEDFLAG, false);
     for (j = PCB->NetlistLib.Menu[i].EntryN, entry = PCB->NetlistLib.Menu[i].Entry; j; j--, entry++)
     { /* For each component (pin/pad) in the net. */
       if (SeekPad(entry, &conn, false))
@@ -439,7 +440,7 @@ gsvit_create_netlist (void)
      */
     gsvit_build_net_from_selected (currNet);
 
-    ClearFlagOnAllObjects (false, FOUNDFLAG | SELECTEDFLAG);
+    ClearFlagOnAllObjects (FOUNDFLAG | SELECTEDFLAG, false);
     FreeConnectionLookupMemory ();
   }
 
@@ -1311,7 +1312,7 @@ gsvit_xml_out (char *gsvit_basename)
   XOUT_ELEMENT ("comment", "Made with PCB gsvit export HID");
   XOUT_NEWLINE ();
   {
-    char buff[0x100];
+    char buff[0x100 + 1];
     char* src = buff;
     t = time (NULL);
     strncpy (buff, ctime(&t), 0x100);
