@@ -48,6 +48,7 @@
 #endif
 
 extern HID ghid_hid;
+extern HID_DRAW ghid_graphics;
 
 /* Sets priv->u_gc to the "right" GC to use (wrt mask or window)
 */
@@ -181,8 +182,8 @@ set_clip (render_priv *priv, GdkGC *gc)
 /*!
  * \brief Draw the grid on the 2D canvas
  */
-static void
-ghid_draw_grid (void)
+void
+ghid_draw_grid (BoxType * region)
 {
   static GdkPoint *points = 0;
   static int npoints = 0;
@@ -840,7 +841,7 @@ redraw_region (GdkRectangle *rect)
   /* Draw all of the PCB stuff, elements, traces, etc. */
   hid_expose_callback (&ghid_hid, &region, 0);
   
-  ghid_draw_grid ();
+  ghid_graphics.draw_grid (&region);
 
   /* In some cases we are called with the crosshair still off */
   if (priv->attached_invalidate_depth == 0)
@@ -860,10 +861,10 @@ redraw_region (GdkRectangle *rect)
 }
 
 void
-ghid_invalidate_lr (int left, int right, int top, int bottom)
+ghid_invalidate_lr (Coord left, Coord right, Coord top, Coord bottom)
 {
-  int dleft, dright, dtop, dbottom;
-  int minx, maxx, miny, maxy;
+  Coord dleft, dright, dtop, dbottom;
+  Coord minx, maxx, miny, maxy;
   GdkRectangle rect;
 
   dleft = Vx (left);
