@@ -36,12 +36,14 @@
 
 #include "global.h"
 #include "pcb-printf.h"
+#include "object_list.h"
 
 int
 main (int argc, char *argv[])
 {
   initialize_units ();
   pcb_printf_register_tests ();
+  object_list_register_tests ();
 
   g_test_init (&argc, &argv, NULL);
   g_test_run ();
