@@ -55,6 +55,7 @@
 #include "error.h"
 #include "file.h"
 #include "find.h"
+#include "flags.h"
 #include "misc.h"
 #include "mymem.h"
 #include "polygon.h"
@@ -470,7 +471,7 @@ GatherSubnets (NetListType *Netl, bool NoWarn, bool AndRats)
   for (m = 0; Netl->NetN > 0 && m < Netl->NetN; m++)
     {
       a = &Netl->Net[m];
-      ClearFlagOnAllObjects (false, DRCFLAG);
+      ClearFlagOnAllObjects (DRCFLAG, false);
       RatFindHook (a->Connection[0].type, a->Connection[0].ptr1,
                    a->Connection[0].ptr2, a->Connection[0].ptr2,
                    false, DRCFLAG, AndRats);
@@ -549,7 +550,7 @@ GatherSubnets (NetListType *Netl, bool NoWarn, bool AndRats)
       if (!NoWarn)
 	Warned |= CheckShorts (a->Connection[0].menu);
     }
-  ClearFlagOnAllObjects (false, DRCFLAG);
+  ClearFlagOnAllObjects (DRCFLAG, false);
   return (Warned);
 }
 
@@ -917,7 +918,7 @@ AddNet (void)
   static int ratDrawn = 0;
   char name1[256], *name2;
   Cardinal group1, group2;
-  char ratname[20];
+  char ratname[22];
   int found;
   void *ptr1, *ptr2, *ptr3;
   LibraryMenuType *menu;
