@@ -748,17 +748,28 @@ IsPointOnLineEnd (Coord X, Coord Y, RatType *Line)
  * \brief Checks if a line intersects with a PV.
  *
  * <pre>
- * let the point be (X,Y) and the line (X1,Y1)(X2,Y2)
- * the length of the line is
+ * let the point be (X,Y) and the line (X1,Y1)(X2,Y2).
+ * Let L be a vector along the line: 
  *
- *   L = ((X2-X1)^2 + (Y2-Y1)^2)^0.5
+ *   vec(L) = (X2-X1, Y2-Y1)
+ *       L  = ((X2-X1)^2 + (Y2-Y1)^2)^0.5
+ *
+ * Let P be a vector from the endpoint of the line to the point in question:
+ * The vector P is: 
+ *
+ *   vec(P) = (X-X1, Y-Y1)
  * 
  * let Q be the point of perpendicular projection of (X,Y) onto the line
  *
  *   QX = X1 + D1*(X2-X1) / L
  *   QY = Y1 + D1*(Y2-Y1) / L
- * 
- * with (from vector geometry)
+ *
+ * where D1 is the distance from (X1, Y1) to (QX, QY). The magnitude of D1
+ * can be written as:
+ *
+ *   D1 = vec(L) . vec(P) / abs(L)    (dot product)
+ *
+ * or (from vector geometry):
  *
  *        (Y1-Y)(Y1-Y2)+(X1-X)(X1-X2)
  *   D1 = ---------------------------
@@ -768,7 +779,13 @@ IsPointOnLineEnd (Coord X, Coord Y, RatType *Line)
  *   D1 > L   Q is on forward extension of the line
  *   else     Q is on the line
  *
- * the signed distance from (X,Y) to Q is
+ * With some coordinate switcheroos, we can get a vector perpendicular to L
+ *
+ *                 Lp_x     Lp_y
+ *   vec (Lp) =  (Y2-Y1, -(X2-X1))
+ *
+ * The distance from the line to the point, D2, can be computed with a
+ * similar dot product. The signed distance from (X,Y) to Q is
  *
  *        (Y2-Y1)(X-X1)-(X2-X1)(Y-Y1)
  *   D2 = ----------------------------
@@ -1123,6 +1140,9 @@ IsPointOnArc (Coord X, Coord Y, Coord Radius, ArcType *Arc)
       ang1 = NormalizeAngle (Arc->StartAngle + Arc->Delta);
       ang2 = NormalizeAngle (Arc->StartAngle);
     }
+  /* This could be the case if one of the angles was negative or > 360
+   * degrees before the call to NormalizeAngles 
+   * */
   if (ang1 > ang2)
     ang2 += 360;
   /* Make sure full circles aren't treated as zero-length arcs */
@@ -1131,8 +1151,14 @@ IsPointOnArc (Coord X, Coord Y, Coord Radius, ArcType *Arc)
 
   if (Y > Arc->Y)
     p_ang = -p_ang;
+  /* In pcb, theta = 0 points to the left (-x) */
   p_ang += 180;
 
+  /*If either angle is greater than 360, then we're into the second time
+   * around the circle, so, we need to make sure our target is also. 
+   * */
+  if ((ang2 > 360) && p_ang < ang1) p_ang += 360;
+
   /* Check point is outside arc range, check distance from endpoints */
   if (ang1 >= p_ang || ang2 <= p_ang)
     {
@@ -1157,6 +1183,74 @@ IsPointOnArc (Coord X, Coord Y, Coord Radius, ArcType *Arc)
   return fabs (Distance (X, Y, Arc->X, Arc->Y) - Arc->Width) < Radius + Arc->Thickness / 2;
 }
 
+static unsigned int
+SearchLayerObjectInternal (LayerType *layer,
+                           unsigned int Type,
+                           unsigned int HigherAvail,
+                           double HigherBound,
+                           void **Result1,
+                           void **Result2,
+                           void **Result3)
+{
+  int locked = Type & LOCKED_TYPE;
+
+  if (!layer->On)
+    return NO_TYPE;
+
+  SearchLayer = layer;
+
+  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 &&
+      Type & POLYGONPOINT_TYPE &&
+      SearchPointByLocation (locked, (LayerType **)Result1, (PolygonType **) Result2, (PointType **) Result3))
+    return POLYGONPOINT_TYPE;
+
+  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 &&
+      Type & LINEPOINT_TYPE &&
+      SearchLinePointByLocation (locked, (LayerType **)Result1, (LineType **) Result2, (PointType **) Result3))
+    return LINEPOINT_TYPE;
+
+  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 && Type & LINE_TYPE
+      && SearchLineByLocation (locked, (LayerType **)Result1, (LineType **) Result2, (LineType **) Result3))
+    return LINE_TYPE;
+
+  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 &&
+      Type & ARCPOINT_TYPE &&
+      SearchArcPointByLocation (locked, (LayerType **)Result1, (ArcType **) Result2, (PointType **) Result3))
+    return ARCPOINT_TYPE;
+
+  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 && Type & ARC_TYPE &&
+      SearchArcByLocation (locked, (LayerType **)Result1, (ArcType **) Result2, (ArcType **) Result3))
+    return ARC_TYPE;
+
+  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 && Type & TEXT_TYPE
+      && SearchTextByLocation (locked, (LayerType **)Result1, (TextType **) Result2, (TextType **) Result3))
+    return TEXT_TYPE;
+
+  if (Type & POLYGON_TYPE &&
+      SearchPolygonByLocation (locked, (LayerType **)Result1, (PolygonType **) Result2, (PolygonType **) Result3))
+    {
+      if (HigherAvail)
+        {
+          BoxType *box =
+            &(*(PolygonType **) Result2)->BoundingBox;
+          double area =
+            (double) (box->X2 - box->X1) * (double) (box->X2 - box->X1);
+          /* XXX: BEHAVIOURAL CHANGE */
+          if (HigherBound < area)
+//            break;
+            return NO_TYPE;
+          else
+            return POLYGON_TYPE;
+        }
+      else
+        {
+          return POLYGON_TYPE;
+        }
+    }
+
+  return NO_TYPE;
+}
+
 /*!
  * \brief Searches for any kind of object or for a set of object types
  * the calling routine passes two pointers to allocated memory for
@@ -1184,8 +1278,9 @@ SearchObjectByLocation (unsigned Type,
   void **pr1 = &r1, **pr2 = &r2, **pr3 = &r3;
   int i;
   double HigherBound = 0;
-  int HigherAvail = NO_TYPE;
+  unsigned int HigherAvail = NO_TYPE;
   int locked = Type & LOCKED_TYPE;
+  unsigned int type;
   /* setup variables used by local functions */
   PosX = X;
   PosY = Y;
@@ -1265,88 +1360,35 @@ SearchObjectByLocation (unsigned Type,
       HigherBound = (double) (box->X2 - box->X1) * (double) (box->Y2 - box->Y1);
       HigherAvail = ELEMENT_TYPE;
     }
+/* uncomment if merged with peterc_layers
+  type = SearchLayerObjectInternal (&PCB->Data->SOLDERMASKLAYER, Type, HigherAvail, HigherBound, Result1, Result2, Result3);
+  if (type != NO_TYPE)
+    return type;
+*/
+  type = SearchLayerObjectInternal (&PCB->Data->SILKLAYER, Type, HigherAvail, HigherBound, Result1, Result2, Result3);
+  if (type != NO_TYPE)
+    return type;
 
-  for (i = -1; i < max_copper_layer + 1; i++)
+  for (i = 0; i < max_copper_layer; i++)
     {
-      if (i < 0)
-	SearchLayer = &PCB->Data->SILKLAYER;
-      else if (i < max_copper_layer)
-	SearchLayer = LAYER_ON_STACK (i);
-      else
-	{
-	  SearchLayer = &PCB->Data->BACKSILKLAYER;
-	  if (!PCB->InvisibleObjectsOn)
-	    continue;
-	}
-      if (SearchLayer->On)
-	{
-	  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 &&
-	      Type & POLYGONPOINT_TYPE &&
-	      SearchPointByLocation (locked,
-				     (LayerType **) Result1,
-				     (PolygonType **) Result2,
-				     (PointType **) Result3))
-	    return (POLYGONPOINT_TYPE);
-
-	  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 &&
-	      Type & LINEPOINT_TYPE &&
-	      SearchLinePointByLocation (locked,
-					 (LayerType **) Result1,
-					 (LineType **) Result2,
-					 (PointType **) Result3))
-	    return (LINEPOINT_TYPE);
-
-	  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 && Type & LINE_TYPE
-	      && SearchLineByLocation (locked,
-				       (LayerType **) Result1,
-				       (LineType **) Result2,
-				       (LineType **) Result3))
-	    return (LINE_TYPE);
-
-    if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 &&
-	      Type & ARCPOINT_TYPE &&
-	      SearchArcPointByLocation (locked,
-					(LayerType **) Result1,
-					(ArcType **) Result2,
-					(PointType **) Result3))
-	    return (ARCPOINT_TYPE);
-
-	  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 && Type & ARC_TYPE &&
-	      SearchArcByLocation (locked,
-				   (LayerType **) Result1,
-				   (ArcType **) Result2,
-				   (ArcType **) Result3))
-	    return (ARC_TYPE);
-
-	  if ((HigherAvail & (PIN_TYPE | PAD_TYPE)) == 0 && Type & TEXT_TYPE
-	      && SearchTextByLocation (locked,
-				       (LayerType **) Result1,
-				       (TextType **) Result2,
-				       (TextType **) Result3))
-	    return (TEXT_TYPE);
-
-	  if (Type & POLYGON_TYPE &&
-	      SearchPolygonByLocation (locked,
-				       (LayerType **) Result1,
-				       (PolygonType **) Result2,
-				       (PolygonType **) Result3))
-	    {
-	      if (HigherAvail)
-		{
-		  BoxType *box =
-		    &(*(PolygonType **) Result2)->BoundingBox;
-		  double area =
-		    (double) (box->X2 - box->X1) * (double) (box->X2 - box->X1);
-		  if (HigherBound < area)
-		    break;
-		  else
-		    return (POLYGON_TYPE);
-		}
-	      else
-		return (POLYGON_TYPE);
-	    }
-	}
+      type = SearchLayerObjectInternal (LAYER_ON_STACK (i), Type, HigherAvail, HigherBound, Result1, Result2, Result3);
+      if (type != NO_TYPE)
+        return type;
     }
+
+  if (PCB->InvisibleObjectsOn)
+    {
+      type = SearchLayerObjectInternal (&PCB->Data->BACKSILKLAYER, Type, HigherAvail, HigherBound, Result1, Result2, Result3);
+      if (type != NO_TYPE)
+        return type;
+
+/* uncomment if merged with peterc_layers
+      type = SearchLayerObjectInternal (&PCB->Data->BACKSOLDERMASKLAYER, Type, HigherAvail, HigherBound, Result1, Result2, Result3);
+      if (type != NO_TYPE)
+        return type;
+*/
+    }
+
   /* return any previously found objects */
   if (HigherAvail & PIN_TYPE)
     {
@@ -1426,7 +1468,7 @@ SearchObjectByID (DataType *Base,
 		  void **Result1, void **Result2, void **Result3, int ID,
 		  int type)
 {
-  if (type == LINE_TYPE || type == LINEPOINT_TYPE)
+  if (type & (LINE_TYPE | LINEPOINT_TYPE))
     {
       ALLLINE_LOOP (Base);
       {
@@ -1453,7 +1495,7 @@ SearchObjectByID (DataType *Base,
       }
       ENDALL_LOOP;
     }
-  if (type == ARC_TYPE)
+  if (type & ARC_TYPE)
     {
       ALLARC_LOOP (Base);
       {
@@ -1467,7 +1509,7 @@ SearchObjectByID (DataType *Base,
       ENDALL_LOOP;
     }
 
-  if (type == TEXT_TYPE)
+  if (type & TEXT_TYPE)
     {
       ALLTEXT_LOOP (Base);
       {
@@ -1481,7 +1523,7 @@ SearchObjectByID (DataType *Base,
       ENDALL_LOOP;
     }
 
-  if (type == POLYGON_TYPE || type == POLYGONPOINT_TYPE)
+  if (type & (POLYGON_TYPE | POLYGONPOINT_TYPE))
     {
       ALLPOLYGON_LOOP (Base);
       {
@@ -1491,7 +1533,7 @@ SearchObjectByID (DataType *Base,
 	    *Result2 = *Result3 = (void *) polygon;
 	    return (POLYGON_TYPE);
 	  }
-	if (type == POLYGONPOINT_TYPE)
+	if (type & POLYGONPOINT_TYPE)
 	  POLYGONPOINT_LOOP (polygon);
 	{
 	  if (point->ID == ID)
@@ -1506,7 +1548,7 @@ SearchObjectByID (DataType *Base,
       }
       ENDALL_LOOP;
     }
-  if (type == VIA_TYPE)
+  if (type & VIA_TYPE)
     {
       VIA_LOOP (Base);
       {
@@ -1519,7 +1561,7 @@ SearchObjectByID (DataType *Base,
       END_LOOP;
     }
 
-  if (type == RATLINE_TYPE || type == LINEPOINT_TYPE)
+  if (type & (RATLINE_TYPE | LINEPOINT_TYPE))
     {
       RAT_LOOP (Base);
       {
@@ -1546,9 +1588,9 @@ SearchObjectByID (DataType *Base,
       END_LOOP;
     }
 
-  if (type == ELEMENT_TYPE || type == PAD_TYPE || type == PIN_TYPE
-      || type == ELEMENTLINE_TYPE || type == ELEMENTNAME_TYPE
-      || type == ELEMENTARC_TYPE)
+  if (type & (ELEMENT_TYPE | PAD_TYPE | PIN_TYPE
+      | ELEMENTLINE_TYPE | ELEMENTNAME_TYPE
+      | ELEMENTARC_TYPE))
     /* check pins and elementnames too */
     ELEMENT_LOOP (Base);
   {
@@ -1557,7 +1599,7 @@ SearchObjectByID (DataType *Base,
 	*Result1 = *Result2 = *Result3 = (void *) element;
 	return (ELEMENT_TYPE);
       }
-    if (type == ELEMENTLINE_TYPE)
+    if (type & ELEMENTLINE_TYPE)
       ELEMENTLINE_LOOP (element);
     {
       if (line->ID == ID)
@@ -1568,7 +1610,7 @@ SearchObjectByID (DataType *Base,
 	}
     }
     END_LOOP;
-    if (type == ELEMENTARC_TYPE)
+    if (type & ELEMENTARC_TYPE)
       ARC_LOOP (element);
     {
       if (arc->ID == ID)
@@ -1579,7 +1621,7 @@ SearchObjectByID (DataType *Base,
 	}
     }
     END_LOOP;
-    if (type == ELEMENTNAME_TYPE)
+    if (type & ELEMENTNAME_TYPE)
       ELEMENTTEXT_LOOP (element);
     {
       if (text->ID == ID)
@@ -1590,7 +1632,7 @@ SearchObjectByID (DataType *Base,
 	}
     }
     END_LOOP;
-    if (type == PIN_TYPE)
+    if (type & PIN_TYPE)
       PIN_LOOP (element);
     {
       if (pin->ID == ID)
@@ -1601,7 +1643,7 @@ SearchObjectByID (DataType *Base,
 	}
     }
     END_LOOP;
-    if (type == PAD_TYPE)
+    if (type & PAD_TYPE)
       PAD_LOOP (element);
     {
       if (pad->ID == ID)
@@ -1615,7 +1657,9 @@ SearchObjectByID (DataType *Base,
   }
   END_LOOP;
 
+#ifdef DEBUG
   Message ("hace: Internal error, search for ID %d failed\n", ID);
+#endif /* DEBUG */
   return (NO_TYPE);
 }
 
